from rabbitmqtesttool import commandline, connection


def main():
    options = commandline.parse_command_line()
    for broker in options.BROKER:
        connection, channel = connection.open_connection(
            broker, options.vhost, options.user, options.password,
            options.queue, options.durable)
        if connection is None:
            continue
        if options.send:
            print("sending one message")
            channel.basic_publish(exchange="",
                                  routing_key=options.queue,
                                  body=options.send)
            break

        elif options.get:
            print("getting one message")
            method_frame, header_frame, body = channel.basic_get(options.queue)
            if method_frame:
                print("message %s %s '%s'" %
                      (method_frame, message_frame, body.decode("utf-8")))
                channel.basic_ack(method_frame.delivery_tag)
            else:
                print("no message received")

        elif options.list:
            print("message list on broker %s" % broker)
            messages = []
            while True:
                method_frame, header_frame, body = channel.basic_get(
                    options.queue)
                if method_frame:
                    messages.append((method_frame, header_frame, body))
                    channel.basic_ack(method_frame.delivery_tag)
                    print("message %s %s body: '%s'" %
                          (method_frame, header_frame, body.decode("utf-8")))
                else:
                    break
            for _, _, body in messages:
                channel.basic_publish(exchange="",
                                      routing_key=options.queue,
                                      body=body)

        elif options.delete:
            print("deleting queue %s" % options.delete)
            channel.queue_delete(options.delete)
            break

        connection.close()



import unittest
import sys

try:
    # python 3.4+ should use builtin unittest.mock not mock package
    from unittest.mock import patch
except ImportError:
    from mock import patch

from rabbitmqtesttool import commandline


class TestCommandLine(unittest.TestCase):

    def setUp(self):
        self.args = ["rabbit-tools", "127.0.0.1"]

    def testBasic(self):
        with patch.object(sys, 'argv', self.args):
            options = commandline.parse_command_line()
            self.assertTrue(isinstance(options.BROKER, list))
            self.assertEquals(len(options.BROKER), 1)
            self.assertEquals(options.BROKER[0], "127.0.0.1")



import setuptools
from os import path

this_directory = path.abspath(path.dirname(__file__))

try:
    with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
        long_description = f.read()
except TypeError:
    with open(path.join(this_directory, 'README.md')) as f:
        long_description = f.read()

setuptools.setup(
    name="RabbitMQ Test Tool",
    version="1.1.4",
    description="A simple test script to test a RabbitMQ cluster",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Nicolas Bock",
    packages=setuptools.find_packages(),
    entry_points={
        "console_scripts": [
            "rabbitmq-test-tool = rabbitmqtesttool.main:main",
        ],
    }
)
